@@ -21,15 +21,7 @@ import mobius
 import pymobius.xml
 from gi.repository import GdkPixbuf
 from gi.repository import Gtk
-
-# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-# Extension metadata
-# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-EXTENSION_ID = 'part-catalogue'
-EXTENSION_NAME = 'Part Catalogue'
-EXTENSION_AUTHOR = 'Eduardo Aguiar'
-EXTENSION_VERSION = '1.11'
-EXTENSION_DESCRIPTION = 'Part catalogue and manager'
+from metadata import *
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # @brief Windows constants
@@ -53,19 +45,16 @@ class Widget(object):
     # @brief initialize widget
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     def __init__(self):
-        self.__widget = Gtk.VBox()
-        self.__widget.on_widget_stopped = self.on_widget_stopped  # workaround for using generic widgets with workarea
-        self.__mediator = pymobius.mediator.copy()
+        self.__widget = mobius.ui.box(mobius.ui.box.orientation_vertical)
         self.__widget.set_border_width(5)
         self.__widget.set_spacing(5)
-        self.__widget.show()
-
-        factory = self.__mediator.call('ui.new-factory')
+        self.__widget.set_visible(True)
+        self.__mediator = pymobius.mediator.copy()
 
         # menubar
         menubar = Gtk.MenuBar()
         menubar.show()
-        self.__widget.pack_start(menubar, False, False, 0)
+        self.__widget.add_child(menubar, mobius.ui.box.fill_none)
 
         item = Gtk.MenuItem.new_with_mnemonic('_File')
         item.show()
@@ -117,22 +106,21 @@ class Widget(object):
         # working area
         hpaned = Gtk.HPaned()
         hpaned.show()
-        self.__widget.pack_start(hpaned, True, True, 0)
+        self.__widget.add_child(hpaned, mobius.ui.box.fill_with_widget)
 
         # part vbox
-        part_vbox = Gtk.VBox()
+        part_vbox = mobius.ui.box(mobius.ui.box.orientation_vertical)
         part_vbox.set_spacing(4)
-        part_vbox.show()
-        hpaned.pack1(part_vbox, False, True)
+        part_vbox.set_visible(True)
+        hpaned.pack1(part_vbox.get_ui_widget(), False, True)
 
         # category combobox
         datastore = Gtk.ListStore.new([GdkPixbuf.Pixbuf, str, object])
         datastore.set_sort_column_id(CATEGORY_NAME, Gtk.SortType.ASCENDING)
-        category_manager = mobius.core.category_manager()
 
-        for category in category_manager.get_categories():
-            image_buffer = factory.new_image_buffer_from_data(category.icon_data, 32, 32)
-            icon = image_buffer.get_ui_widget()
+        for category in mobius.framework.get_categories():
+            image = mobius.ui.new_icon_from_data(category.icon_data, mobius.ui.icon.size_dnd)
+            icon = image.get_ui_widget().get_pixbuf()
             datastore.append((icon, category.name, category))
 
         self.__category_combobox = Gtk.ComboBox.new_with_model(datastore)
@@ -147,12 +135,12 @@ class Widget(object):
         self.__category_combobox.pack_start(renderer, True)
         self.__category_combobox.add_attribute(renderer, 'text', CATEGORY_NAME)
 
-        part_vbox.pack_start(self.__category_combobox, False, True, 0)
+        part_vbox.add_child(self.__category_combobox, mobius.ui.box.fill_none)
 
         # part listview
         frame = Gtk.Frame()
         frame.show()
-        part_vbox.pack_start(frame, True, True, 0)
+        part_vbox.add_child(frame, mobius.ui.box.fill_with_widget)
 
         sw = Gtk.ScrolledWindow()
         sw.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
@@ -177,30 +165,30 @@ class Widget(object):
         self.__part_listview.append_column(tvcolumn)
 
         # buttons
-        hbox = Gtk.HBox()
-        hbox.show()
-        part_vbox.pack_start(hbox, False, True, 0)
+        hbox = mobius.ui.box(mobius.ui.box.orientation_horizontal)
+        hbox.set_visible(True)
+        part_vbox.add_child(hbox, mobius.ui.box.fill_none)
 
-        image = Gtk.Image.new_from_icon_name('list-remove', Gtk.IconSize.BUTTON)
-        self.__remove_button = Gtk.Button.new_with_mnemonic("_Remove")
-        self.__remove_button.set_image(image)
+        self.__remove_button = mobius.ui.button()
+        self.__remove_button.set_icon_by_name('list-remove')
+        self.__remove_button.set_text("_Remove")
         self.__remove_button.set_sensitive(False)
-        self.__remove_button.connect('clicked', self.__on_part_remove)
-        self.__remove_button.show()
-        hbox.pack_start(self.__remove_button, False, True, 0)
+        self.__remove_button.set_callback('clicked', self.__on_part_remove)
+        self.__remove_button.set_visible(True)
+        hbox.add_child(self.__remove_button, mobius.ui.box.fill_none)
 
         # attribute listview
         self.__listview = self.__mediator.call('ui.new-widget', 'attribute-list')
         self.__listview.set_is_editable(True)
         self.__listview.set_sensitive(False)
         self.__listview.set_report_id('part.attributes')
-        self.__listview.set_report_app('%s v%s' % (EXTENSION_NAME, EXTENSION_VERSION))
+        self.__listview.set_report_app(f'{EXTENSION_NAME} v{EXTENSION_VERSION}')
         self.__listview.set_control(self, 'listview')
         self.__listview.show()
         hpaned.pack2(self.__listview.get_ui_widget(), True, True)
 
         # select last used category, if any
-        last_category_selected = mobius.core.get_config('part-catalogue.last-category')
+        last_category_selected = mobius.framework.get_config('part-catalogue.last-category')
         last_category_idx = -1
 
         model = self.__category_combobox.get_model()
@@ -218,9 +206,9 @@ class Widget(object):
         self.__copy_and_paste_data = {}
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    # @brief return low level widget
+    # @brief Return widget
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    def get_ui_widget(self):
+    def get_widget(self):
         return self.__widget
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -240,8 +228,8 @@ class Widget(object):
             for part in self.__mediator.call('part.get_by_category', category.id):
                 part_model.append((part.id, part))
 
-            transaction = mobius.core.new_config_transaction()
-            mobius.core.set_config('part-catalogue.last-category', category.id)
+            transaction = mobius.framework.new_config_transaction()
+            mobius.framework.set_config('part-catalogue.last-category', category.id)
             transaction.commit()
 
         self.__category = category
@@ -262,8 +250,7 @@ class Widget(object):
 
         if treeiter:
             part = model.get_value(treeiter, PART_OBJECT)
-            category_manager = mobius.core.category_manager()
-            category = category_manager.get_category(part.category)
+            category = mobius.framework.get_category(part.category)
 
             for attr in category.get_attributes():
                 if attr.id != 'part_id' and attr.is_editable:
@@ -314,19 +301,19 @@ class Widget(object):
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief handle part->remove event
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    def __on_part_remove(self, widget, *args):
+    def __on_part_remove(self):
         if not self.__part:
             return
 
         # show confirmation dialog
-        dialog = mobius.ui.message_dialog(mobius.ui.MESSAGE_DIALOG_TYPE_QUESTION)
-        dialog.text = "You are about to remove part '%s'. Are you sure?" % self.__part.id
-        dialog.add_button(mobius.ui.BUTTON_YES)
-        dialog.add_button(mobius.ui.BUTTON_NO)
-        dialog.set_default_response(mobius.ui.BUTTON_NO)
+        dialog = mobius.ui.message_dialog(mobius.ui.message_dialog.type_question)
+        dialog.text = f"You are about to remove part '{self.__part.id}'. Are you sure?"
+        dialog.add_button(mobius.ui.message_dialog.button_yes)
+        dialog.add_button(mobius.ui.message_dialog.button_no)
+        dialog.set_default_response(mobius.ui.message_dialog.button_no)
         rc = dialog.run()
 
-        if rc != mobius.ui.BUTTON_YES:
+        if rc != mobius.ui.message_dialog.button_yes:
             return
 
         # remove part from model
@@ -458,9 +445,9 @@ class Widget(object):
         self.__on_category_selection_changed(self.__category_combobox)
 
         # show result
-        dialog = mobius.ui.message_dialog(mobius.ui.MESSAGE_DIALOG_TYPE_INFO)
-        dialog.text = 'Parts processed: %d' % len(parts)
-        dialog.add_button(mobius.ui.BUTTON_OK)
+        dialog = mobius.ui.message_dialog(mobius.ui.message_dialog.type_info)
+        dialog.text = f'Parts processed: {len(parts):d}'
+        dialog.add_button(mobius.ui.message_dialog.button_ok)
         rc = dialog.run()
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -492,7 +479,7 @@ def open_working_area():
         working_area.set_default_size(600, 400)
         working_area.set_title(EXTENSION_NAME)
         working_area.set_icon(icon_path)
-        working_area.set_widget(widget.get_ui_widget())
+        working_area.set_widget(widget)
         working_area.app_widget = widget
 
     working_area.show()
@@ -541,13 +528,13 @@ def on_attribute_modified(item, attr_id, old_value, new_value):
 
     # unknown part ID. Open up part catalogue dialog
     if not part:
-        dialog = mobius.ui.message_dialog(mobius.ui.MESSAGE_DIALOG_TYPE_QUESTION)
+        dialog = mobius.ui.message_dialog(mobius.ui.message_dialog.type_question)
         dialog.text = f"Would you like to include part '{new_value}'?"
-        dialog.add_button(mobius.ui.BUTTON_YES)
-        dialog.add_button(mobius.ui.BUTTON_NO)
+        dialog.add_button(mobius.ui.message_dialog.button_yes)
+        dialog.add_button(mobius.ui.message_dialog.button_no)
         rc = dialog.run()
 
-        if rc == mobius.ui.BUTTON_YES:
+        if rc == mobius.ui.message_dialog.button_yes:
             working_area = open_working_area()
             widget = working_area.app_widget
             part = pymobius.mediator.call('part.new', item.category, new_value.strip())
