@@ -16,16 +16,16 @@
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include "segment_writer.hpp"
-#include <mobius/encoder/data_encoder.h>
-#include <mobius/core/application.h>
-#include <mobius/datetime/datetime.h>
-#include <mobius/datetime/conv_iso_string.h>
-#include <mobius/string_functions.h>
-#include <mobius/zlib_functions.h>
-#include <mobius/charset.h>
-#include <mobius/exception.inc>
-#include <mobius/io/writer_evaluator.h>
-#include <mobius/crypt/hash_functor.h>
+#include <mobius/core/application.hpp>
+#include <mobius/core/charset.hpp>
+#include <mobius/core/crypt/hash_functor.hpp>
+#include <mobius/core/datetime/datetime.hpp>
+#include <mobius/core/datetime/conv_iso_string.hpp>
+#include <mobius/core/encoder/data_encoder.hpp>
+#include <mobius/core/string_functions.hpp>
+#include <mobius/core/zlib_functions.hpp>
+#include <mobius/core/exception.inc>
+#include <mobius/core/io/writer_evaluator.hpp>
 #include <stdexcept>
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -69,7 +69,7 @@ static constexpr int SECTOR_SIZE = 512;
 // @return std::uint32_t
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static std::uint32_t
-digest_to_uint32_t (const mobius::bytearray& digest)
+digest_to_uint32_t (const mobius::core::bytearray& digest)
 {
   return std::uint32_t (digest[0]) << 24 |
          std::uint32_t (digest[1]) << 16 |
@@ -81,15 +81,15 @@ digest_to_uint32_t (const mobius::bytearray& digest)
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // @brief Constructor
-// @param writer generic mobius::io::writer object
+// @param writer generic mobius::core::io::writer object
 // @param segment_idx segment index, starting from 1
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-segment_writer::segment_writer (mobius::io::writer writer, std::uint16_t segment_number)
+segment_writer::segment_writer (mobius::core::io::writer writer, std::uint16_t segment_number)
   : writer_ (writer),
     segment_number_ (segment_number),
     chunk_sectors_ (CHUNK_SECTORS),
     sector_size_ (SECTOR_SIZE),
-    guid_ (mobius::bytearray (16))
+    guid_ (mobius::core::bytearray (16))
 {
 }
 
@@ -117,9 +117,9 @@ segment_writer::create ()
 // @return the number of bytes written
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 segment_writer::size_type
-segment_writer::write (const mobius::bytearray& arg_data)
+segment_writer::write (const mobius::core::bytearray& arg_data)
 {
-  mobius::bytearray data = chunk_data_ + arg_data;
+  mobius::core::bytearray data = chunk_data_ + arg_data;
   size_type bytes = 0;
 
   // write data chunks
@@ -150,7 +150,7 @@ segment_writer::write (const mobius::bytearray& arg_data)
 
   // otherwise, error
   else if (chunk_data_.size () > 0)
-    throw std::runtime_error (mobius::MOBIUS_EXCEPTION_MSG ("error writing chunk data"));
+    throw std::runtime_error (MOBIUS_EXCEPTION_MSG ("error writing chunk data"));
 
   return bytes;
 }
@@ -213,9 +213,9 @@ segment_writer::close ()
 void
 segment_writer::_write_file_header (std::uint16_t segment_idx)
 {
-  const mobius::bytearray EWF_SIGNATURE = {'E', 'V', 'F', 0x09, 0x0d, 0x0a, 0xff, 0x00};
+  const mobius::core::bytearray EWF_SIGNATURE = {'E', 'V', 'F', 0x09, 0x0d, 0x0a, 0xff, 0x00};
 
-  mobius::encoder::data_encoder encoder (writer_);
+  mobius::core::encoder::data_encoder encoder (writer_);
   encoder.encode_bytearray (EWF_SIGNATURE);
   encoder.encode_uint8 (0x01);
   encoder.encode_uint16_le (segment_idx);
@@ -237,10 +237,10 @@ segment_writer::_write_section_header (const std::string& name, size_type size)
     next_offset += HEADER_SIZE + size;
 
   // encode section header
-  mobius::crypt::hash_functor hash_functor ("adler32");
-  auto writer = mobius::io::writer_evaluator (writer_, hash_functor);
+  mobius::core::crypt::hash_functor hash_functor ("adler32");
+  auto writer = mobius::core::io::writer_evaluator (writer_, hash_functor);
 
-  mobius::encoder::data_encoder encoder (writer);
+  mobius::core::encoder::data_encoder encoder (writer);
   encoder.encode_string_by_size (name, 16);
   encoder.encode_uint64_le (next_offset);
   encoder.encode_uint64_le (HEADER_SIZE + size);
@@ -256,7 +256,7 @@ segment_writer::_write_section_header (const std::string& name, size_type size)
 // @param data section data
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
-segment_writer::_write_section_data (const mobius::bytearray& data)
+segment_writer::_write_section_data (const mobius::core::bytearray& data)
 {
   writer_.write (data);
 }
@@ -271,17 +271,17 @@ segment_writer::_write_header_section ()
 {
   // format header metadata
   mobius::core::application app;
-  mobius::datetime::datetime dt_now = mobius::datetime::now ();
+  mobius::core::datetime::datetime dt_now = mobius::core::datetime::now ();
 
   std::string acquisition_tool = app.get_title ();
   std::string acquisition_platform = app.get_os_name ();
   std::string drive_model = drive_vendor_ + ' ' + drive_model_;
 
-  std::string acquisition_datetime = mobius::datetime::datetime_to_iso_string (dt_now);
-  acquisition_datetime = mobius::string::replace (acquisition_datetime, "-", " ");
-  acquisition_datetime = mobius::string::replace (acquisition_datetime, ":", " ");
-  acquisition_datetime = mobius::string::replace (acquisition_datetime, "T", " ");
-  acquisition_datetime = mobius::string::replace (acquisition_datetime, "Z", "");
+  std::string acquisition_datetime = mobius::core::datetime::datetime_to_iso_string (dt_now);
+  acquisition_datetime = mobius::core::string::replace (acquisition_datetime, "-", " ");
+  acquisition_datetime = mobius::core::string::replace (acquisition_datetime, ":", " ");
+  acquisition_datetime = mobius::core::string::replace (acquisition_datetime, "T", " ");
+  acquisition_datetime = mobius::core::string::replace (acquisition_datetime, "Z", "");
 
   std::string header_utf8 = "1\n"
                             "main\n"
@@ -306,16 +306,16 @@ segment_writer::_write_header_section ()
                             "\n\n";
 
   // write two "header2" sections
-  mobius::bytearray header_utf16 = mobius::conv_charset (header_utf8, "utf-8", "utf-16");
+  mobius::core::bytearray header_utf16 = mobius::core::conv_charset (header_utf8, "utf-8", "utf-16");
 
-  const mobius::bytearray data_header2 = mobius::zlib_compress (header_utf16);
+  const mobius::core::bytearray data_header2 = mobius::core::zlib_compress (header_utf16);
   _write_section_header ("header2", data_header2.size ());
   _write_section_data (data_header2);
   _write_section_header ("header2", data_header2.size ());
   _write_section_data (data_header2);
 
   // write "header" section
-  const mobius::bytearray data_header = mobius::zlib_compress (header_utf8);
+  const mobius::core::bytearray data_header = mobius::core::zlib_compress (header_utf8);
   _write_section_header ("header", data_header.size ());
   _write_section_data (data_header);
 }
@@ -346,11 +346,11 @@ segment_writer::_write_volume_section (const std::string& section_name)
   size_type sectors = (total_size_ + sector_size_ - 1) / sector_size_;
   size_type chunk_count = (total_size_ + chunk_size_ - 1) / chunk_size_;
 
-  mobius::crypt::hash_functor hash_functor ("adler32");
-  auto writer = mobius::io::writer_evaluator (writer_, hash_functor);
+  mobius::core::crypt::hash_functor hash_functor ("adler32");
+  auto writer = mobius::core::io::writer_evaluator (writer_, hash_functor);
 
   // encode metadata
-  mobius::encoder::data_encoder encoder (writer);
+  mobius::core::encoder::data_encoder encoder (writer);
   encoder.encode_uint32_le (1);                         // \todo media type
   encoder.encode_uint32_le (chunk_count);
   encoder.encode_uint32_le (chunk_sectors_);
@@ -382,10 +382,10 @@ segment_writer::_write_hash_section ()
   _write_section_header ("hash", 36);
 
   // encode section
-  mobius::crypt::hash_functor hash_functor ("adler32");
-  auto writer = mobius::io::writer_evaluator (writer_, hash_functor);
+  mobius::core::crypt::hash_functor hash_functor ("adler32");
+  auto writer = mobius::core::io::writer_evaluator (writer_, hash_functor);
 
-  mobius::encoder::data_encoder encoder (writer);
+  mobius::core::encoder::data_encoder encoder (writer);
   encoder.encode_bytearray (md5_hash_);
   encoder.fill (16, 0);                                 // padding
 
@@ -409,10 +409,10 @@ segment_writer::_write_table_section (const std::string& name)
   _write_section_header (name, section_size);
 
   // write section metadata
-  mobius::crypt::hash_functor hash_functor ("adler32");
-  auto writer = mobius::io::writer_evaluator (writer_, hash_functor);
+  mobius::core::crypt::hash_functor hash_functor ("adler32");
+  auto writer = mobius::core::io::writer_evaluator (writer_, hash_functor);
 
-  mobius::encoder::data_encoder encoder (writer);
+  mobius::core::encoder::data_encoder encoder (writer);
   encoder.encode_uint32_le (entries);
   encoder.fill (4, 0);
   encoder.encode_uint64_le (sector_offset_);
@@ -422,9 +422,9 @@ segment_writer::_write_table_section (const std::string& name)
   encoder.encode_uint32_le (adler32_value);             // Adler-32 CRC
 
   // write offsets
-  hash_functor = mobius::crypt::hash_functor ("adler32");
-  writer = mobius::io::writer_evaluator (writer_, hash_functor);
-  encoder = mobius::encoder::data_encoder (writer);
+  hash_functor = mobius::core::crypt::hash_functor ("adler32");
+  writer = mobius::core::io::writer_evaluator (writer_, hash_functor);
+  encoder = mobius::core::encoder::data_encoder (writer);
 
   for (auto offset : chunk_offset_list_)
     encoder.encode_uint32_le (offset);
@@ -459,7 +459,7 @@ segment_writer::_can_write_chunk_data ()
 // @return true/false if chunk could be written
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
-segment_writer::_write_chunk_data (mobius::bytearray data)
+segment_writer::_write_chunk_data (mobius::core::bytearray data)
 {
   // create new sectors section, if necessary
   if (sector_offset_ == -1)
@@ -475,7 +475,7 @@ segment_writer::_write_chunk_data (mobius::bytearray data)
   if (compression_level_ > 0)
     {
       int level = (compression_level_ == 2) ? 9 : 1;
-      mobius::bytearray compressed_data = zlib_compress (data, level);
+      mobius::core::bytearray compressed_data = mobius::core::zlib_compress (data, level);
 
       if (compressed_data.size () < data.size ())
         {
@@ -485,12 +485,12 @@ segment_writer::_write_chunk_data (mobius::bytearray data)
     }
 
   // write data
-  mobius::crypt::hash_functor hash_functor ("adler32");
-  auto writer = mobius::io::writer_evaluator (writer_, hash_functor);
+  mobius::core::crypt::hash_functor hash_functor ("adler32");
+  auto writer = mobius::core::io::writer_evaluator (writer_, hash_functor);
   writer.write (data);
 
   // encode ADLER-32 hash
-  mobius::encoder::data_encoder encoder (writer);
+  mobius::core::encoder::data_encoder encoder (writer);
   std::uint32_t hash_value = digest_to_uint32_t (hash_functor.get_digest ());
   encoder.encode_uint32_le (hash_value);                // Adler-32 CRC
 
